@@ -24,22 +24,23 @@ else:
 
 __all__ = (
     "DeleteThingShadowRequestRequestTypeDef",
-    "DeleteThingShadowResponseTypeDef",
-    "GetRetainedMessageRequestRequestTypeDef",
-    "GetRetainedMessageResponseTypeDef",
-    "GetThingShadowRequestRequestTypeDef",
-    "GetThingShadowResponseTypeDef",
-    "ListNamedShadowsForThingRequestRequestTypeDef",
-    "ListNamedShadowsForThingResponseTypeDef",
-    "ListRetainedMessagesRequestListRetainedMessagesPaginateTypeDef",
-    "ListRetainedMessagesRequestRequestTypeDef",
-    "ListRetainedMessagesResponseTypeDef",
-    "PaginatorConfigTypeDef",
-    "PublishRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
+    "GetRetainedMessageRequestRequestTypeDef",
+    "GetThingShadowRequestRequestTypeDef",
+    "ListNamedShadowsForThingRequestRequestTypeDef",
+    "PaginatorConfigTypeDef",
+    "ListRetainedMessagesRequestRequestTypeDef",
     "RetainedMessageSummaryTypeDef",
+    "PublishRequestRequestTypeDef",
     "UpdateThingShadowRequestRequestTypeDef",
+    "DeleteThingShadowResponseTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "GetRetainedMessageResponseTypeDef",
+    "GetThingShadowResponseTypeDef",
+    "ListNamedShadowsForThingResponseTypeDef",
     "UpdateThingShadowResponseTypeDef",
+    "ListRetainedMessagesRequestListRetainedMessagesPaginateTypeDef",
+    "ListRetainedMessagesResponseTypeDef",
 )
 
 _RequiredDeleteThingShadowRequestRequestTypeDef = TypedDict(
@@ -63,11 +64,14 @@ class DeleteThingShadowRequestRequestTypeDef(
     pass
 
 
-DeleteThingShadowResponseTypeDef = TypedDict(
-    "DeleteThingShadowResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "payload": StreamingBody,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -78,17 +82,6 @@ GetRetainedMessageRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetRetainedMessageResponseTypeDef = TypedDict(
-    "GetRetainedMessageResponseTypeDef",
-    {
-        "topic": str,
-        "payload": bytes,
-        "qos": int,
-        "lastModifiedTime": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredGetThingShadowRequestRequestTypeDef = TypedDict(
     "_RequiredGetThingShadowRequestRequestTypeDef",
     {
@@ -110,14 +103,6 @@ class GetThingShadowRequestRequestTypeDef(
     pass
 
 
-GetThingShadowResponseTypeDef = TypedDict(
-    "GetThingShadowResponseTypeDef",
-    {
-        "payload": StreamingBody,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListNamedShadowsForThingRequestRequestTypeDef = TypedDict(
     "_RequiredListNamedShadowsForThingRequestRequestTypeDef",
     {
@@ -141,20 +126,12 @@ class ListNamedShadowsForThingRequestRequestTypeDef(
     pass
 
 
-ListNamedShadowsForThingResponseTypeDef = TypedDict(
-    "ListNamedShadowsForThingResponseTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "results": List[str],
-        "nextToken": str,
-        "timestamp": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListRetainedMessagesRequestListRetainedMessagesPaginateTypeDef = TypedDict(
-    "ListRetainedMessagesRequestListRetainedMessagesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
@@ -168,21 +145,13 @@ ListRetainedMessagesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListRetainedMessagesResponseTypeDef = TypedDict(
-    "ListRetainedMessagesResponseTypeDef",
+RetainedMessageSummaryTypeDef = TypedDict(
+    "RetainedMessageSummaryTypeDef",
     {
-        "retainedTopics": List["RetainedMessageSummaryTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "topic": str,
+        "payloadSize": int,
+        "qos": int,
+        "lastModifiedTime": int,
     },
     total=False,
 )
@@ -210,28 +179,6 @@ class PublishRequestRequestTypeDef(
     pass
 
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-RetainedMessageSummaryTypeDef = TypedDict(
-    "RetainedMessageSummaryTypeDef",
-    {
-        "topic": str,
-        "payloadSize": int,
-        "qos": int,
-        "lastModifiedTime": int,
-    },
-    total=False,
-)
-
 _RequiredUpdateThingShadowRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateThingShadowRequestRequestTypeDef",
     {
@@ -254,10 +201,71 @@ class UpdateThingShadowRequestRequestTypeDef(
     pass
 
 
+DeleteThingShadowResponseTypeDef = TypedDict(
+    "DeleteThingShadowResponseTypeDef",
+    {
+        "payload": StreamingBody,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetRetainedMessageResponseTypeDef = TypedDict(
+    "GetRetainedMessageResponseTypeDef",
+    {
+        "topic": str,
+        "payload": bytes,
+        "qos": int,
+        "lastModifiedTime": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetThingShadowResponseTypeDef = TypedDict(
+    "GetThingShadowResponseTypeDef",
+    {
+        "payload": StreamingBody,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListNamedShadowsForThingResponseTypeDef = TypedDict(
+    "ListNamedShadowsForThingResponseTypeDef",
+    {
+        "results": List[str],
+        "nextToken": str,
+        "timestamp": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateThingShadowResponseTypeDef = TypedDict(
     "UpdateThingShadowResponseTypeDef",
     {
         "payload": StreamingBody,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListRetainedMessagesRequestListRetainedMessagesPaginateTypeDef = TypedDict(
+    "ListRetainedMessagesRequestListRetainedMessagesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListRetainedMessagesResponseTypeDef = TypedDict(
+    "ListRetainedMessagesResponseTypeDef",
+    {
+        "retainedTopics": List[RetainedMessageSummaryTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
